#include "hardware.h"
#include "timer.h"

volatile uint32_t global_timer = 0;

void SysTick_Handler(void)
{
	global_timer++;
}

void TIMER16_0_IRQHandler(void)
{
	LPC_TMR16B0->IR = 0x1f; // clear interrupt flag
}

void delay(uint32_t time)
{
	uint32_t start = global_timer;
	while (global_timer < start + time);
}

void pwm_set(uint8_t channel, uint32_t proc)
{
	if (proc>100) proc = 100;
	switch (channel)
	{
	case 0:
		LPC_TMR16B0->MR1 = PWM_PERIOD*(100-proc)/100;
		break;
	case 1:
		LPC_TMR16B0->MR2 = PWM_PERIOD*(100-proc)/100;
		break;
	}
}

void timer_init(void)
{
	SysTick_Config(480000); // 10ms

	LPC_SYSCON->SYSAHBCLKCTRL |= 0x80; // CT16B0 clock enable
	LPC_TMR16B0->TCR = 2; // timer reset
	LPC_TMR16B0->MCR = 3; // reset and interrupt on MR0
	LPC_TMR16B0->MR0 = PWM_PERIOD; // 1ms
	LPC_TMR16B0->MR1 = PWM_PERIOD;
	LPC_TMR16B0->MR2 = PWM_PERIOD;
	LPC_TMR16B0->EMR = 0x80;
	LPC_TMR16B0->PR = 0; // prescaler 1
	LPC_TMR16B0->TCR = 1; // timer enable
	NVIC_EnableIRQ(TIMER_16_0_IRQn); // interrupt enable

	LPC_IOCON->PIO0_9 = 0x02;
	LPC_IOCON->SWCLK_PIO0_10 = 0x03;
	LPC_TMR16B0->PWMC = 0x06;
}


