#include "hardware.h"
#include "uart.h"

void uart_init(void)
{
	LPC_SYSCON->SYSAHBCLKCTRL |= 0x1000;

	LPC_IOCON->PIO1_6 = 0x01;
	LPC_IOCON->PIO1_7 = 0x01;
	LPC_UART->FCR = 0x07;

	LPC_UART->LCR = 0x80; // DLAB = 1;
	LPC_UART->DLL = BAUDRATEDIVISOR & 0x00ff;
	LPC_UART->DLM = (BAUDRATEDIVISOR >> 8) & 0x00ff;
	LPC_UART->LCR &= ~0x80; // DLAB = 0;

	//Set mode
	LPC_UART->LCR = 0x03; //8 bit word length, 1 stop bit, No parity

}

void uart_send_byte(const uint8_t byte)
{
  while(!(LPC_UART->LSR & 0x20));
  LPC_UART->THR = byte;
}

void uart_send(const char *s)
{
	while (*s) {
		if (*s=='\n') uart_send_byte('\r');
		uart_send_byte(*s);
		s++;
	}
}

void uart_send_int(const int32_t x)
{
	int32_t value = x;
	char buf[12];
	char* p = buf;

	if (value<0) {
		uart_send_byte('-');
		value = -value;
	}
	if (value==0) {
		uart_send_byte('0');
		return;
	}
	while (value) {
		*p = value % 10 + '0';
		value /= 10;
		p++;
	}
	do {
		p--;
		uart_send_byte(*p);
	} while (p!=buf);
}

uint8_t uart_recv_byte(void)
{
  while(!(LPC_UART->LSR & 0x01));
  return LPC_UART->RBR;
}


